(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    110666,       2407]
NotebookOptionsPosition[    104416,       2207]
NotebookOutlinePosition[    105031,       2233]
CellTagsIndexPosition[    104944,       2228]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["HCN DG-EVB in redundant internal coordinates", "Subtitle",
 CellChangeTimes->{{3.421418088194728*^9, 3.4214181028280973`*^9}}],

Cell[TextData[{
 StyleBox["Notes:",
  FontWeight->"Bold"],
 "\n   \nThis notebook reads fchk files containing coordinates, energies, \
gradients and hessians for reactant, product, transition state, and \
additional points on the surface.\n\n###############\n Gaussian stores all \
values in a.u. and standard orientation in the fchk file\n\n Distance = bohrs\
\n Angles = radian\n Energy = hartree\n Gradient = hartree/bohr\n Hessian = \
hartree/bohr^2\n###############\n\nThe notebook reads an IRC fchk file (from \
the HPC IRC following algorithm located in L123.exe, the corrected \
coordinates and energies are read)\n\nA reduced number of internal \
coordinates can be used to fit V12sq (see the EVB Surface Fitting section)\nA \
reduced number of points can be used for the distributed Gussian fit (see the \
EVB Surface Fitting section)\n\nTo perform an EVB fit, update the \
SetDirectory statement and any other options in input section, then evaluate \
the outermost cell over here.  ",
 StyleBox["---------------------------->",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]
}], "Text",
 CellChangeTimes->{{3.4211658572262583`*^9, 3.421165860565464*^9}, {
  3.421165918505851*^9, 3.4211659992892523`*^9}, {3.421583346865282*^9, 
  3.421583425893856*^9}, {3.421583527849957*^9, 3.421583568182987*^9}, {
  3.421583926020019*^9, 3.421583926485379*^9}}],

Cell[CellGroupData[{

Cell["Preliminaries", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"$TextStyle", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
    RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"FontFamily", "\[Rule]", "\<\"Helvetica\"\>"}], ",", 
   RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.421583941040316*^9, 3.421584027815003*^9, 3.4215841176244297`*^9, 
   3.421585054832838*^9, 3.437414462881441*^9, 3.437421952642387*^9, {
   3.437421994463019*^9, 3.43742202291324*^9}, 3.4374220828083963`*^9, 
   3.4374221499399357`*^9, 3.437422201547338*^9, 3.437422240984126*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", "Chemistry`EVB`"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Input", "Section"],

Cell["\<\
To avoid clobbering variables of similiar names, please use variable names of \
the form iName to hold input data.\
\>", "Text",
 CellChangeTimes->{{3.4214181842223473`*^9, 3.421418184645219*^9}, 
   3.421583494000621*^9}],

Cell[CellGroupData[{

Cell["Set working directory", "Subsection",
 ScreenStyleEnvironment->"Presentation",
 PrintingStyleEnvironment->"Presentation",
 ShowCellLabel->False,
 Magnification->1.25],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "SetDirectory", "[", 
   "\"\</Users/jsonnenb/Documents/Research/ONR/EVB fits/hcn_gas_5\>\"", "]"}],
   ";"}]], "Input",
 CellChangeTimes->{{3.421166058114293*^9, 3.421166059605595*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
File names. All files must have the same number of redundant internal \
coordinates. \
\>", "Subsection",
 ScreenStyleEnvironment->"Presentation",
 PrintingStyleEnvironment->"Presentation",
 ShowCellLabel->False,
 Magnification->1.25],

Cell[BoxData[{
 RowBox[{
  RowBox[{"iReactant", "=", "\"\<hcn_5.fchk\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iProduct", "=", "\"\<hnc_5.fchk\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iTS", "=", "\"\<hcn_ts_5.fchk\>\""}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{
    "data", " ", "points", " ", "along", " ", "IRC", " ", "that", " ", "are", 
     " ", "used", " ", "for", " ", "analyzing", " ", "the", " ", "EVB", " ", 
     RowBox[{"fit", "."}]}], " ", "*)"}],
   FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"IRCFile", "=", "\"\<hcn_irc.fchk\>\""}], ";"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"A", " ", "2"}], "-", 
     RowBox[{"D", " ", "PES", " ", 
      RowBox[{"scan", "."}]}]}], " ", "*)"}],
   FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"GridFile", "=", "\"\<\>\""}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"GridCoordX", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"GridCoordY", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Ngrid", "=", "0"}], ";"}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Repulsive Term coordinates", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"icoordV11", "=", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3", ",", "0", ",", "0"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"icoordV22", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "0", ",", "0"}], "}"}]}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Control the use of gradients and Hessians in the DG fit at points other than \
the TS.\
\>", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"iNoGrad", "=", "False"}], ";", 
  RowBox[{"iNoHess", "=", "False"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Enable figure file generation for manuscripts and the like.", \
"Subsection",
 ScreenStyleEnvironment->"Presentation",
 PrintingStyleEnvironment->"Presentation",
 ShowCellLabel->False,
 Magnification->1.25],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"iFigures", "=", "0"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.4215839478278303`*^9, {3.421584004236005*^9, 3.421584033451552*^9}, 
   3.4215841198655024`*^9, 3.421585056620055*^9, 3.4374144765462008`*^9, 
   3.437421957436681*^9, {3.437421995167927*^9, 3.4374220236674147`*^9}, 
   3.437422083433502*^9, 3.437422150556623*^9, 3.43742220221975*^9, 
   3.4374222416748962`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Enable use of previously determined beta as starting guess.", \
"Subsection",
 ScreenStyleEnvironment->"Presentation",
 PrintingStyleEnvironment->"Presentation",
 ShowCellLabel->False,
 CellChangeTimes->{{3.434827059397477*^9, 3.434827075946116*^9}},
 Magnification->1.25],

Cell[BoxData[
 RowBox[{
  RowBox[{"iBeta", "=", "True"}], ";"}]], "Input",
 CellChangeTimes->{
  3.4348269884069633`*^9, {3.434827084349894*^9, 3.434827102376202*^9}, {
   3.435000846343*^9, 3.435000848028*^9}, {3.435007303237*^9, 
   3.435007304959*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Enable debugging checks and dump printing.", "Subsection",
 ScreenStyleEnvironment->"Presentation",
 PrintingStyleEnvironment->"Presentation",
 ShowCellLabel->False,
 Magnification->1.25],

Cell[BoxData[
 RowBox[{
  RowBox[{"iDebug", "=", "10"}], ";", 
  RowBox[{"iDump", "=", "0"}], ";"}]], "Input",
 CellChangeTimes->{3.437421171642909*^9, 3.4374214126188803`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions", "Section"],

Cell[CellGroupData[{

Cell["Display MB of memory currently in use", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MBinUse", "[", "]"}], ":=", 
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Currently using \>\"", ",", 
    RowBox[{"N", "[", 
     RowBox[{
      RowBox[{"MemoryInUse", "[", "]"}], "/", 
      SuperscriptBox["2", "20"]}], "]"}], ",", "\"\< MB of memory.\>\""}], 
   "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Condition Number of a matrix. May blow up if the matrix is not invertible.\
\>", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OneNorm", "[", "m_", "]"}], ":=", 
  RowBox[{"Max", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Norm", "[", 
       RowBox[{"#", ",", "1"}], "]"}], "&"}], ",", "m"}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TwoNorm", "[", "m_", "]"}], ":=", 
  RowBox[{"Max", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Norm", "[", 
       RowBox[{"#", ",", "2"}], "]"}], "&"}], ",", "m"}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ConditionNumber2", "[", "m_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"TwoNorm", "[", 
    RowBox[{"Inverse", "[", "m", "]"}], "]"}], "*", 
   RowBox[{"TwoNorm", "[", "m", "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ConditionNumber", "[", "m_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"OneNorm", "[", 
    RowBox[{"Inverse", "[", "m", "]"}], "]"}], "*", 
   RowBox[{"OneNorm", "[", "m", "]"}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBinUse", "[", "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Currently using \"\>", "\[InvisibleSpace]", 
   "9.944129943847656`", "\[InvisibleSpace]", "\<\" MB of memory.\"\>"}],
  SequenceForm["Currently using ", 9.944129943847656, " MB of memory."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158412763932*^9, 3.421585057912005*^9, 3.4374144865028353`*^9, 
   3.4374219579466*^9, {3.437421995740417*^9, 3.437422024261815*^9}, 
   3.4374220837808332`*^9, 3.437422150899158*^9, 3.437422202588292*^9, 
   3.43742224200766*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate EVB surface", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nDG", "=", "3"}]], "Input",
 CellChangeTimes->{
  3.421594049622143*^9, 3.421595624339498*^9, 3.4216023290974894`*^9, {
   3.4361169555625*^9, 3.4361169565625*^9}, 3.436117162671875*^9, 
   3.43612141059375*^9, 3.4361219589375*^9, 3.43612513821875*^9, 
   3.43613248734375*^9, 3.43613257978125*^9, 3.436132848109375*^9, {
   3.436194348296875*^9, 3.436194348546875*^9}, 3.4372550625365*^9, {
   3.43725510069275*^9, 3.437255186927125*^9}, 3.437331071833644*^9, 
   3.4373957048882017`*^9, 3.437421879919428*^9, 3.4374220199411182`*^9}],

Cell[BoxData["3"], "Output",
 CellChangeTimes->{
  3.421593527416809*^9, 3.421593963815804*^9, 3.421594051919518*^9, 
   3.421594273474373*^9, 3.421595103674*^9, 3.421595367274531*^9, 
   3.421595643066065*^9, 3.4216023506572866`*^9, 3.4350924422539997`*^9, 
   3.435092515502*^9, 3.435092797602*^9, 3.435092885791*^9, 3.435093216722*^9,
    3.436117189203125*^9, 3.436117310015625*^9, 3.43611950328125*^9, 
   3.43612127003125*^9, 3.43612141578125*^9, 3.436121490421875*^9, 
   3.436121586890625*^9, 3.43612170684375*^9, 3.43612179009375*^9, {
   3.4361218695*^9, 3.43612189046875*^9}, {3.43612195090625*^9, 
   3.43612196140625*^9}, 3.436122098359375*^9, 3.43612437071875*^9, 
   3.43612456390625*^9, 3.436124799546875*^9, 3.436125142140625*^9, 
   3.436126306109375*^9, 3.4361268211875*^9, 3.436128308859375*^9, 
   3.436129062390625*^9, {3.43612940484375*^9, 3.43612942334375*^9}, 
   3.43612969353125*^9, 3.436130644828125*^9, 3.436131066453125*^9, 
   3.43613146559375*^9, 3.436131953796875*^9, 3.436132191515625*^9, 
   3.436132489578125*^9, 3.436132581828125*^9, 3.436132832421875*^9, 
   3.43613287771875*^9, 3.43613526190625*^9, 3.43613621546875*^9, 
   3.436137610234375*^9, 3.43618460515625*^9, 3.43618941628125*^9, 
   3.436190856546875*^9, 3.436191946421875*^9, 3.436193097046875*^9, 
   3.436194354921875*^9, 3.43619613825*^9, 3.436198455484375*^9, 
   3.436202322671875*^9, 3.436206013359375*^9, 3.436565368146*^9, 
   3.436619006724125*^9, 3.437162638114625*^9, {3.437231081474*^9, 
   3.4372311030365*^9}, 3.437244720224*^9, 3.437244757552125*^9, 
   3.4372550264115*^9, 3.437255071270875*^9, {3.437255102958375*^9, 
   3.437255167614625*^9}, 3.4373275789135513`*^9, 3.43733107418781*^9, 
   3.437395742081045*^9, 3.437399056173801*^9, 3.437399114577737*^9, 
   3.4374086538093243`*^9, 3.437412934136491*^9, 3.437413350283654*^9, 
   3.437413406047739*^9, 3.437421300329115*^9, {3.437421415720434*^9, 
   3.4374214372061577`*^9}, 3.4374214975514297`*^9, 3.4374219582229*^9, {
   3.4374219958547087`*^9, 3.4374220244084806`*^9}, 3.437422083920574*^9, 
   3.4374221512086067`*^9, 3.4374222029086847`*^9, 3.437422242328397*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"reactant", ",", " ", "product", ",", " ", "TS", ",", " ", 
    RowBox[{"others", ";", " ", 
     RowBox[{
      RowBox[{"except", " ", "for", " ", "nDG"}], "=", "1"}]}]}], " ", "*)"}],
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"UseRP", "=", "True"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Switch", "[", 
     RowBox[{"nDG", ",", "\[IndentingNewLine]", 
      StyleBox["3",
       FontColor->GrayLevel[0]], ",", 
      RowBox[{
       RowBox[{"alpha", "=", 
        RowBox[{"{", 
         RowBox[{"0.3", ",", "0.3", ",", "0.45"}], "}"}]}], ";"}], ",", 
      "\[IndentingNewLine]", "1", ",", 
      RowBox[{
       RowBox[{"alpha", "=", 
        RowBox[{"{", "0.6343963705908164`", "}"}]}], ";", 
       RowBox[{"UseRP", "=", "False"}], ";"}]}], "\[IndentingNewLine]", "]"}],
     ";"}]}]}]], "Input",
 CellChangeTimes->{{3.421594214990321*^9, 3.421594215365445*^9}, {
   3.421594259588469*^9, 3.421594260543841*^9}, {3.436117088875*^9, 
   3.43611712953125*^9}, {3.436117170734375*^9, 3.436117173453125*^9}, 
   3.436117293703125*^9, {3.436119378359375*^9, 3.436119381921875*^9}, {
   3.436121405921875*^9, 3.43612140634375*^9}, {3.436121486125*^9, 
   3.43612148659375*^9}, {3.43612158165625*^9, 3.43612158340625*^9}, 
   3.436121673203125*^9, {3.436121784359375*^9, 3.43612178621875*^9}, 
   3.436121939546875*^9, 3.436122091765625*^9, 3.436124366890625*^9, 
   3.43612455953125*^9, 3.436124795078125*^9, 3.4361249885625*^9, 
   3.436125133046875*^9, 3.436126294625*^9, {3.436126815625*^9, 
   3.436126818046875*^9}, {3.436128305265625*^9, 3.436128305421875*^9}, 
   3.436129058890625*^9, {3.4361293929375*^9, 3.436129393390625*^9}, 
   3.4361296789375*^9, {3.436130636421875*^9, 3.436130641484375*^9}, {
   3.436131063484375*^9, 3.436131063859375*^9}, 3.436131461984375*^9, {
   3.436131930703125*^9, 3.4361319495*^9}, {3.43613218309375*^9, 
   3.436132184234375*^9}, 3.436132447234375*^9, {3.436132863875*^9, 
   3.4361328690625*^9}, {3.436135205625*^9, 3.436135256625*^9}, 
   3.436136210765625*^9, {3.436137605375*^9, 3.436137606921875*^9}, 
   3.436184594484375*^9, 3.43618941121875*^9, {3.43619085125*^9, 
   3.43619085178125*^9}, 3.43619191465625*^9, 3.436192944859375*^9, 
   3.43619613453125*^9, {3.43619845115625*^9, 3.43619845159375*^9}, {
   3.43620231890625*^9, 3.436202319125*^9}, {3.436206008984375*^9, 
   3.436206009515625*^9}, 3.436565340849125*^9, {3.436619000567875*^9, 
   3.436619000974125*^9}, 3.437162624724*^9, {3.43724467063025*^9, 
   3.4372446707865*^9}, {3.437421221727005*^9, 3.437421263154875*^9}, 
   3.437421939830594*^9, {3.43742198776607*^9, 3.4374219901670218`*^9}, {
   3.437422076857297*^9, 3.437422080156789*^9}, {3.4374221416239233`*^9, 
   3.43742214656936*^9}, {3.437422195345071*^9, 3.437422198394328*^9}, 
   3.4374222348912983`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"previously", " ", "determined", " ", "$B", " ", "values"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"betafilename", "=", 
     RowBox[{"\"\<Beta-\>\"", "<>", 
      RowBox[{"ToString", "[", "nDG", "]"}], "<>", "\"\<.txt\>\""}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Count", "[", 
         RowBox[{
          RowBox[{"FileNames", "[", "]"}], ",", "betafilename"}], "]"}], 
        "\[Equal]", "1"}], " ", "&&", " ", "iBeta"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Guess", "=", 
        RowBox[{"ReadList", "[", 
         RowBox[{"betafilename", ",", "Number"}], "]"}]}], ";"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Guess", "=", "Automatic"}], ";"}]}], "\[IndentingNewLine]", 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Length", "[", "Guess", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.434826774981058*^9, 3.434826813971819*^9}, 
   3.434827020475934*^9, {3.434827118861854*^9, 3.434827137802361*^9}, {
   3.4348272794057903`*^9, 3.434827283568796*^9}, {3.4348274080212593`*^9, 
   3.434827480216357*^9}, {3.434827634674159*^9, 3.4348276792732973`*^9}, {
   3.434827751919635*^9, 3.4348277813294573`*^9}, {3.434829639050087*^9, 
   3.434829640813073*^9}, {3.43482969597332*^9, 3.434829777685588*^9}, {
   3.4348299842914867`*^9, 3.434830014241911*^9}, {3.434830124518196*^9, 
   3.434830139091716*^9}, {3.434831212882193*^9, 3.4348312181855307`*^9}}],

Cell[BoxData["63"], "Output",
 CellChangeTimes->{
  3.434831219514971*^9, 3.4348325009000998`*^9, 3.434832781868763*^9, {
   3.4348328176391363`*^9, 3.434832841332365*^9}, 3.4348328919141693`*^9, 
   3.434833157768956*^9, 3.434833218637692*^9, 3.4348359458733463`*^9, 
   3.434836438399084*^9, 3.434838350979312*^9, {3.4348384005506144`*^9, 
   3.4348384126413*^9}, 3.434838552719667*^9, 3.434838666177204*^9, 
   3.434838875236762*^9, 3.4350009442650003`*^9, 3.435001204414*^9, 
   3.435001359049*^9, 3.435002008877*^9, 3.435003411467*^9, 3.435004073208*^9,
    3.435007334027*^9, 3.4350633487196627`*^9, 3.435063488088663*^9, 
   3.4350636873396626`*^9, 3.435064767157663*^9, 3.4350656311886625`*^9, 
   3.435092442281*^9, 3.435092515533*^9, 3.4350927977679996`*^9, 
   3.435092885925*^9, 3.435093216855*^9, 3.435094216263*^9, 3.435095358325*^9,
    3.4361171894375*^9, 3.43611731021875*^9, 3.436119504015625*^9, 
   3.43612127025*^9, 3.43612141590625*^9, 3.4361214905*^9, 
   3.436121587015625*^9, 3.43612170696875*^9, 3.436121790234375*^9, {
   3.436121869625*^9, 3.436121890671875*^9}, {3.436121951109375*^9, 
   3.43612196153125*^9}, 3.436122098484375*^9, 3.4361243713125*^9, 
   3.43612456453125*^9, 3.436124800203125*^9, 3.43612514275*^9, 
   3.436126306734375*^9, 3.436126821328125*^9, 3.436128309484375*^9, 
   3.436129062984375*^9, {3.43612940521875*^9, 3.436129424*^9}, 
   3.43612969409375*^9, 3.43613064521875*^9, 3.436131067046875*^9, 
   3.43613146646875*^9, 3.4361319544375*^9, 3.436132191609375*^9, 
   3.4361324896875*^9, 3.436132581953125*^9, 3.436132832671875*^9, 
   3.43613287784375*^9, 3.43613526203125*^9, 3.43613621603125*^9, 
   3.4361376103125*^9, 3.436184605390625*^9, 3.436189416375*^9, 
   3.436190856625*^9, 3.436191946546875*^9, 3.43619309715625*^9, 
   3.436194355*^9, 3.436196138328125*^9, 3.4361984555625*^9, 
   3.436202322734375*^9, 3.4362060134375*^9, 3.436565368536625*^9, 
   3.4366190068335*^9, 3.43716263888025*^9, {3.43723108163025*^9, 
   3.437231103208375*^9}, 3.43724472044275*^9, 3.437244757770875*^9, 
   3.437255026645875*^9, 3.43725507163025*^9, {3.43725510325525*^9, 
   3.437255167958375*^9}, 3.437327579840219*^9, 3.437331074896521*^9, 
   3.437395742663178*^9, 3.437399056669751*^9, 3.4373991152230663`*^9, 
   3.437408654660651*^9, 3.437409218358788*^9, 3.437412580628334*^9, 
   3.43741293489589*^9, 3.4374133506660624`*^9, 3.437413406473846*^9, 
   3.437421300741499*^9, 3.437421333312202*^9, {3.437421416141773*^9, 
   3.4374214981622143`*^9}, 3.437421959960425*^9, {3.4374219961094637`*^9, 
   3.437422024653283*^9}, 3.437422084394411*^9, 3.437422151485973*^9, 
   3.437422203175439*^9, 3.43742224250965*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "EVB", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Alpha", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"AlphaMultiplier", "\[Rule]", "1.1`"}], ",", 
   RowBox[{"AlphaThreshold", "\[Rule]", "15"}], ",", 
   RowBox[{"AverageAlpha", "\[Rule]", "False"}], ",", 
   RowBox[{"CheckTS", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotIRC", "\[Rule]", "True"}], ",", 
   RowBox[{"RepulsivePotential", "\[Rule]", "True"}], ",", 
   RowBox[{"ReverseIRC", "\[Rule]", "False"}], ",", 
   RowBox[{"ScaleFactor", "\[Rule]", "1"}], ",", 
   RowBox[{"StartGuess", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"UseReactantAndProduct", "\[Rule]", "True"}], ",", 
   RowBox[{"V11Coord", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"V22Coord", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"V12Coordinates", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"V12CoordinateTolerance", "\[Rule]", "0"}], ",", 
   RowBox[{"DebugPrint", "\[Rule]", "1"}], ",", 
   RowBox[{"MaxIterations", "\[Rule]", "1000"}], ",", 
   RowBox[{"ResidualPlot", "\[Rule]", "True"}], ",", 
   RowBox[{"Tolerance", "\[Rule]", "1.`*^-9"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.421584150228611*^9, 3.421584201632554*^9, 3.421585058039267*^9, 
   3.437414579323543*^9, 3.437421175131452*^9, 3.4374213008694887`*^9, {
   3.437421416298933*^9, 3.437421437732152*^9}, 3.437421498275773*^9, 
   3.437421960085045*^9, {3.437421996229581*^9, 3.437422024780925*^9}, 
   3.437422084517789*^9, 3.4374221516012793`*^9, 3.437422203317651*^9, 
   3.437422242677644*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EVB", "[", 
  RowBox[{"iReactant", ",", "iProduct", ",", "iTS", ",", "IRCFile", ",", 
   RowBox[{"V11Coord", "\[Rule]", "icoordV11"}], ",", 
   RowBox[{"Alpha", "\[Rule]", "alpha"}], ",", 
   RowBox[{"V22Coord", "\[Rule]", "icoordV22"}], ",", 
   RowBox[{"ReverseIRC", "\[Rule]", "True"}], ",", 
   RowBox[{"UseReactantAndProduct", "\[Rule]", "UseRP"}], ",", 
   RowBox[{"StartGuess", "\[Rule]", "Guess"}], ",", 
   RowBox[{"DebugPrint", "\[Rule]", "iDebug"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.421584190349918*^9, 3.4215841975435123`*^9}, {
   3.437421276973721*^9, 3.4374212947083893`*^9}, 3.4374213863952827`*^9, 
   3.437421428987948*^9, {3.43742148721056*^9, 3.437421492491*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The repulsion coefficient was set to \"\>", 
   "\[InvisibleSpace]", "1", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["The repulsion coefficient was set to ", 1, "."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422242793304*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The \\!\\(\\*SubscriptBox[\\\"V\\\", \\\"11\\\"]\\) repulsive \
coordinate is \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3", ",", "0", ",", "0"}], "}"}], 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "The \!\(\*SubscriptBox[\"V\", \"11\"]\) repulsive coordinate is ", {2, 3, 
   0, 0}, "."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422242931595*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The \\!\\(\\*SubscriptBox[\\\"V\\\", \\\"22\\\"]\\) repulsive \
coordinate is \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "0", ",", "0"}], "}"}], 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "The \!\(\*SubscriptBox[\"V\", \"22\"]\) repulsive coordinate is ", {1, 2, 
   0, 0}, "."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422243036354*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "3", "\[InvisibleSpace]", "\<\" points will be used in the EVB PES \
fit.\"\>"}],
  SequenceForm[3, " points will be used in the EVB PES fit."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.4374222431162643`*^9}],

Cell[BoxData["\<\"The following files were passed to EVB:\"\>"], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422243194996*^9}],

Cell[BoxData["\<\"hcn_5.fchk\"\>"], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422243315091*^9}],

Cell[BoxData["\<\"hnc_5.fchk\"\>"], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422243448492*^9}],

Cell[BoxData["\<\"hcn_ts_5.fchk\"\>"], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422243577828*^9}],

Cell[BoxData["\<\"hcn_irc.fchk\"\>"], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422243703985*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The alpha multiplier was set to \"\>", "\[InvisibleSpace]", 
   "1.1`", "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm["The alpha multiplier was set to ", 1.1, "."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.43742224380986*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The molecular system contains \"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" atoms.\"\>"}],
  SequenceForm["The molecular system contains ", 3, " atoms."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422243930526*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Read in \"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\" internal coordinates.\"\>"}],
  SequenceForm["Read in ", 5, " internal coordinates."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422244037883*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "0", ",", "0"}], "}"}]},
     {"2", 
      RowBox[{"{", 
       RowBox[{"1", ",", "3", ",", "0", ",", "0"}], "}"}]},
     {"3", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "0", ",", "0"}], "}"}]},
     {"4", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "3", ",", "0"}], "}"}]},
     {"5", 
      RowBox[{"{", 
       RowBox[{"1", ",", "3", ",", "2", ",", "0"}], "}"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.43742224415228*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ab initio energies: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "92.35408000869046`"}], ",", 
     RowBox[{"-", "92.33971059419295`"}], ",", 
     RowBox[{"-", "92.24604265259538`"}]}], "}"}]}],
  SequenceForm[
  "Ab initio energies: ", {-92.35408000869046, -92.33971059419295, \
-92.24604265259538}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422244261072*^9}],

Cell[BoxData["\<\"Cartesian Coordinates:\"\>"], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.4374222443503428`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.00123704275`", "0.9325582490000001`", "0.`", 
      RowBox[{"-", "0.0160815557`"}], "2.91707307`", "0.`", "0.00123704275`", 
      
      RowBox[{"-", "1.21606037`"}], "0.`"},
     {"0.0013956859800000002`", 
      RowBox[{"-", "1.38487275`"}], 
      RowBox[{"-", "5.29149252`*^-32"}], 
      RowBox[{"-", "0.0181439177`"}], "2.66425755`", 
      "8.067239049999999`*^-32", "0.0013956859800000002`", 
      "0.8064255640000001`", "2.64694997`*^-32"},
     {"0.155706767`", "1.16827375`", "0.`", 
      RowBox[{"-", "2.02418797`"}], "0.45704336000000007`", "0.`", 
      "0.155706767`", 
      RowBox[{"-", "1.06666941`"}], "0.`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422244444416*^9}],

Cell[BoxData["\<\"Internal Coordinates:\"\>"], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.4374222445263243`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1.9845903881206655`", "2.148618619`", "4.133169723916319`", 
      "3.13286600734074`", "0.004190161615742449`"},
     {"4.0491774451720515`", "2.191298314`", "1.8579347362909913`", 
      "0.004825592303424764`", "3.1310756189980467`"},
     {"2.292987076295863`", "2.2349431600000003`", "2.659631867357092`", 
      "1.2554177880973312`", "0.9607521889477655`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422244611662*^9}],

Cell[BoxData["\<\"Internal gradients:\"\>"], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.4374222447034483`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.00011719085899999999`", 
      RowBox[{"-", "0.000253926626`"}], 
      RowBox[{"-", "0.000143573134`"}], 
      RowBox[{"-", "0.000759565251`"}], "0.00036509655`"},
     {
      RowBox[{"-", "0.0000703204326`"}], 
      RowBox[{"-", "0.000172479079`"}], "0.00010692291199999999`", 
      "0.00020709721800000002`", 
      RowBox[{"-", "0.000450578846`"}]},
     {
      RowBox[{"-", "0.0000232818274`"}], "8.53808074`*^-6", 
      RowBox[{"-", "0.0000186192641`"}], 
      RowBox[{"-", "5.18984589`*^-6"}], 
      RowBox[{"-", "6.933031869999999`*^-6"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422244801991*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Read in \"\>", "\[InvisibleSpace]", "30", 
   "\[InvisibleSpace]", "\<\" forward and \"\>", "\[InvisibleSpace]", "30", 
   "\[InvisibleSpace]", "\<\" reverse IRC steps.\"\>"}],
  SequenceForm["Read in ", 30, " forward and ", 30, " reverse IRC steps."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422244879889*^9}],

Cell[BoxData["\<\"\\!\\(\\*SubscriptBox[\\\"V\\\", \\\"11\\\"]\\)(Blue), \
\\!\\(\\*SubscriptBox[\\\"V\\\", \\\"22\\\"]\\)(Green), and Electronic Energy \
(Red) along the IRC path:\"\>"], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422244961939*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.005], 
    LineBox[{{-3.24499768, 1.420680666338696}, {-3.1405073, 
     3.9382722611165293`}, {-3.03528968, 7.589554595937627}, {-2.92758729, 
     12.202819995037537`}, {-2.81937738, 17.75968996098118}, {-2.71093924, 
     24.231021447894424`}, {-2.6025219, 31.591872209284887`}, {-2.49407894, 
     39.80469760051493}, {-2.38564506, 48.838254175870304`}, {-2.2772049, 
     58.659985740086476`}, {-2.16876811, 69.23602334782626}, {-2.06032868, 
     80.52803470457262}, {-1.95189081, 92.4905986666699}, {-1.84345134, 
     105.06910484193146`}, {-1.73501278, 118.1968655396217}, {-1.62657248, 
     131.79275282130274`}, {-1.51813347, 145.7577853508845}, {-1.40969332, 
     159.97197779529347`}, {-1.30125402, 174.29434082447276`}, {-1.19281333, 
     188.55920541174592`}, {-1.08437405, 
     202.5791108836109}, {-0.9759327980000001, 
     216.14480491951642`}, {-0.867494241, 229.03364515092375`}, {-0.759052219,
      241.0140625105614}, {-0.650616021, 251.85868873039024`}, {-0.542173085, 
     261.3532830407471}, {-0.433743052, 269.31301026767824`}, {-0.32530123, 
     275.59005478201016`}, {-0.21689052700000003`, 
     280.0896360471092}, {-0.10846103600000001`, 282.7705337188507}, {0., 
     283.6519139444745}, {0.10846971000000001`, 282.8091285633897}, {
     0.216902458, 280.3718772572823}, {0.325343716, 276.5110800520371}, {
     0.43378705300000003`, 271.42338686991104`}, {0.542230259, 
     265.31043608242214`}, {0.6506729280000001, 258.35312461408967`}, {
     0.759116199, 250.6916541450911}, {0.867561557, 242.4213303119922}, {
     0.9760091230000001, 233.60647785570382`}, {1.0844576, 
     224.30249481847855`}, {1.19290552, 214.5729182912732}, {1.30135204, 
     204.49730091295334`}, {1.40979687, 194.17042322000344`}, {1.51824012, 
     183.6975677476982}, {1.62668199, 173.18690508073334`}, {1.73512276, 
     162.74476795406107`}, {1.84356276, 152.46829985406532`}, {1.95200217, 
     142.44282951860296`}, {2.06044115, 132.73924543775408`}, {2.1688798, 
     123.41268310371198`}, {2.27731819, 114.50410031065395`}, {2.38575633, 
     106.04185245464933`}, {2.4941942, 98.04379293312653}, {2.60263173, 
     90.51937354482506}, {2.71106885, 83.47384528895346}, {2.81950548, 
     76.90878346523326}, {2.92794151, 70.82418807373907}, {3.03637685, 
     65.22189696417709}, {3.14481138, 60.10453563624487}, {3.25324494, 
     55.478142739030346`}}]}, 
   {RGBColor[0, 0, 1], Thickness[0.005], 
    LineBox[{{-3.24499768, 1.9215143298218933`}, {-3.1405073, 
     4.743753812411136}, {-3.03528968, 8.737554599433563}, {-2.92758729, 
     14.395577579503126`}, {-2.81937738, 21.481155336912266`}, {-2.71093924, 
     30.279439091449742`}, {-2.6025219, 40.84848791639189}, {-2.49407894, 
     53.35942121137087}, {-2.38564506, 67.96057120431072}, {-2.2772049, 
     84.82016096407509}, {-2.16876811, 104.11321564541203`}, {-2.06032868, 
     126.0191663412822}, {-1.95189081, 150.73114324740052`}, {-1.84345134, 
     178.44502415205335`}, {-1.73501278, 209.37793958292627`}, {-1.62657248, 
     243.7530168814688}, {-1.51813347, 
     281.8265868453299}, {-1.508265524346892, 285.65203840530245`}}]}, 
   {RGBColor[0., 0.75, 0.], Thickness[0.005], 
    LineBox[{{2.04889545658837, 285.65203840530245`}, {2.06044115, 
     281.33631720248474`}, {2.1688798, 245.68166650282822`}, {2.27731819, 
     214.3868313548077}, {2.38575633, 186.97520687307247`}, {2.4941942, 
     163.01517739800948`}, {2.60263173, 142.12072224692656`}, {2.71106885, 
     123.95018500941573`}, {2.81950548, 108.20325866277007`}, {2.92794151, 
     94.61670180059441}, {3.03637685, 82.95941995025053}, {3.14481138, 
     73.0277294680512}, {3.25324494, 64.64133082618406}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Reaction coordinate\"", TraditionalForm], 
    FormBox[
     FractionBox[
     "\"Energy\"", 
      "\"\\!\\(\\*SuperscriptBox[\\\"kJmol\\\", \\nRowBox[{\\\"-\\\", \\\"1\\\
\"}]]\\)\""], TraditionalForm]},
  AxesOrigin->{0, 0},
  ImageSize->{400, 300},
  PlotRange->{{-3.24499768, 3.25324494}, {0, 285.65203840530245`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.4374222450802507`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Redundant internal distance between TS structures is \"\>", 
   "\[InvisibleSpace]", "8.97644272272378`*^-9", 
   "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "Redundant internal distance between TS structures is ", 
   8.97644272272378*^-9, "."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422245185*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "5", "\[InvisibleSpace]", "\<\" internal coordinates will be used in \
fitting \\!\\(\\*SubscriptBox[\\\"V\\\", \\\"12\\\"]\\).\"\>"}],
  SequenceForm[
  5, " internal coordinates will be used in fitting \!\(\*SubscriptBox[\"V\", \
\"12\"]\)."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422245255669*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "0", ",", "0"}], "}"}]},
     {"2", 
      RowBox[{"{", 
       RowBox[{"1", ",", "3", ",", "0", ",", "0"}], "}"}]},
     {"3", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3", ",", "0", ",", "0"}], "}"}]},
     {"4", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "3", ",", "0"}], "}"}]},
     {"5", 
      RowBox[{"{", 
       RowBox[{"1", ",", "3", ",", "2", ",", "0"}], "}"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422245336925*^9}],

Cell[BoxData["\<\"Utilizing user supplied initial guess.\"\>"], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422245418351*^9}],

Cell[BoxData["\<\"Solving for B using GMRES.\"\>"], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.43742224551621*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Current alpha values: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.3`", ",", "0.3`", ",", "0.45`"}], "}"}]}],
  SequenceForm["Current alpha values: ", {0.3, 0.3, 0.45}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422245588644*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Norm of \\!\\(\\*SubscriptBox[\\\"r\\\", \\\"0\\\"]\\) = \"\>",
    "\[InvisibleSpace]", "1.2630367120004097`*^-12", 
   "\[InvisibleSpace]", "\<\" , Dimensions: \"\>", "\[InvisibleSpace]", 
   "63"}],
  SequenceForm[
  "Norm of \!\(\*SubscriptBox[\"r\", \"0\"]\) = ", 1.2630367120004097`*^-12, 
   " , Dimensions: ", 63],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422245677759*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Iteration: \"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["Iteration: ", 1],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422245762031*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Residual: \"\>", "\[InvisibleSpace]", 
   "1.230954883222079`*^-12"}],
  SequenceForm["Residual: ", 1.230954883222079*^-12],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.4374222458345947`*^9}],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0, 0, 1], LineBox[{{1., 1.}, {2., 1.230954883222079*^-12}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"GMRES step\"", TraditionalForm], 
    FormBox["\"Residual\"", TraditionalForm]},
  AxesOrigin->{0, Automatic},
  ImageSize->{400, 300},
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422245927094*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Min element in B vector: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "3.1071193387941567`"}]}],
  SequenceForm["Min element in B vector: ", -3.1071193387941567`],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.4374222460540123`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Max element in B vector: \"\>", "\[InvisibleSpace]", 
   "7.184988184463157`"}],
  SequenceForm["Max element in B vector: ", 7.184988184463157],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.4374222461532393`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Mean element in B vector: \"\>", "\[InvisibleSpace]", 
   "0.05011637522688642`"}],
  SequenceForm["Mean element in B vector: ", 0.05011637522688642],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.4374222462201653`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Norm of B vector: \"\>", "\[InvisibleSpace]", 
   "9.663393491824223`"}],
  SequenceForm["Norm of B vector: ", 9.663393491824223],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.42158415056739*^9, 3.421584201970293*^9, 3.421585058594208*^9, 
   3.4374145796217327`*^9, 3.437421175538258*^9, 3.437421301019878*^9, {
   3.437421388172634*^9, 3.4374214378417063`*^9}, 3.4374214985006847`*^9, 
   3.437421960219836*^9, {3.43742199636197*^9, 3.4374220249232388`*^9}, 
   3.437422084724371*^9, 3.437422151761788*^9, 3.4374222035177507`*^9, 
   3.437422246283822*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["store and dump beta if necessary", "Subsection",
 ScreenStyleEnvironment->"Presentation",
 PrintingStyleEnvironment->"Presentation",
 ShowCellLabel->False,
 Magnification->1.25],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"iDump", "\[Equal]", "1"}], ",", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"\"\<Beta-\>\"", "<>", 
      RowBox[{"ToString", "[", 
       RowBox[{"Length", "[", "$CoordDG", "]"}], "]"}], "<>", 
      "\"\<.txt\>\""}], ",", "$B", ",", "\"\<List\>\""}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.434826997366086*^9, 3.434826997772156*^9}, {
  3.434832645621215*^9, 3.4348326511043377`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Remove", "[", "Guess", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.4348272400822906`*^9, 3.4348272466618767`*^9}, {
  3.4348326615324*^9, 3.4348326799587812`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBinUse", "[", "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Currently using \"\>", "\[InvisibleSpace]", 
   "9.952201843261719`", "\[InvisibleSpace]", "\<\" MB of memory.\"\>"}],
  SequenceForm["Currently using ", 9.952201843261719, " MB of memory."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.4372434226615*^9, 3.437250669114625*^9, 3.4372550527865*^9, {
   3.437255092364625*^9, 3.437255172864625*^9}, 3.4373276462333317`*^9, 
   3.437331096889311*^9, 3.437395755568035*^9, 3.437399070093008*^9, 
   3.4373991289389772`*^9, 3.437408668496966*^9, 3.43741294894648*^9, 
   3.437413365178754*^9, 3.437413420475841*^9, 3.4374145865232687`*^9, 
   3.437421184457711*^9, 3.437421304733035*^9, 3.437421401370818*^9, 
   3.4374214453888206`*^9, 3.437421501909794*^9, 3.437421964105969*^9, 
   3.437422000127934*^9, 3.437422034903565*^9, 3.437422096013377*^9, 
   3.437422164685224*^9, 3.437422213545678*^9, 3.43742224665184*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Analyze the EVB Fit", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"First", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"V", "\[Equal]", " ", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], "*", 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["V", "11"], "+", 
             SubscriptBox["V", "22"]}], ")"}]}], "-", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               FractionBox["1", "2"], "*", 
               RowBox[{"(", 
                RowBox[{
                 SubscriptBox["V", "11"], "-", 
                 SubscriptBox["V", "22"]}], ")"}]}], ")"}], "2"], "+", "x"}], 
           "]"}]}]}], ",", "x"}], "]"}], "]"}], "/.", 
     RowBox[{"x", "\[Rule]", 
      SuperscriptBox[
       SubscriptBox["V", "12"], "2"]}]}], "]"}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.437339186173005*^9, 3.4373391883843307`*^9}}],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["V", "12", "2"], "\[Rule]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"V", "-", 
     SubscriptBox["V", "11"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"V", "-", 
     SubscriptBox["V", "22"]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.43733918935921*^9, 3.437395831965209*^9, 
  3.437399139035681*^9, 3.437408676019188*^9, 3.437412949097754*^9, 
  3.437413365350039*^9, 3.437413420629324*^9, 3.4374215682166653`*^9, 
  3.437421964274817*^9, 3.437422000290674*^9, 3.437422035125139*^9, 
  3.4374220961518183`*^9, 3.437422164820786*^9, 3.4374222137015676`*^9, 
  3.4374222468103933`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "AnalyzeEVBfit", "]"}]], "Input",
 CellChangeTimes->{{3.4374077555659847`*^9, 3.4374077635091677`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"AngleAnalysis", "\[Rule]", "False"}], ",", 
   RowBox[{"DecomposeV12", "\[Rule]", "False"}], ",", 
   RowBox[{"HessianNorm", "\[Rule]", "False"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"400", ",", "300"}], "}"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.43740776394527*^9, 3.437408677374529*^9, 
  3.437412949309499*^9, 3.437413365563484*^9, 3.437413420745775*^9, 
  3.437421568603054*^9, 3.4374219643803663`*^9, 3.4374220004021797`*^9, 
  3.437422035310849*^9, 3.437422096263343*^9, 3.437422164941132*^9, 
  3.437422213797925*^9, 3.437422246911539*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "AnalyzeEVBfit"}]], "Input",
 CellChangeTimes->{{3.437407731305887*^9, 3.4374077535814247`*^9}, 
   3.437408693896212*^9}],

Cell[BoxData[
 StyleBox["\<\"AnalyzeEVBfit[AtomicMass] analyzes the EVB fit along the IRC \
utilizing the current EVB global variables. AtomicMass is an optional \
argument containing the atomic mass for each atom in the system. AtomicMass \
is only required when AngleAnalysis is enabled.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.43742224781684*^9},
 CellTags->"Info3437404247-9902564"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AnalyzeEVBfit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.437333218794162*^9, 3.437333243521221*^9}, 
   3.4373336072593727`*^9, {3.437343985992947*^9, 3.4373439909852333`*^9}, 
   3.437345102779917*^9, {3.43739858081579*^9, 3.437398585274695*^9}, {
   3.437400086478726*^9, 3.4374000901734667`*^9}, {3.437400281224248*^9, 
   3.437400289291956*^9}, {3.437406880411166*^9, 3.437406882449649*^9}, 
   3.437407729403167*^9, 3.437412622457279*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reaction barrier: \"\>", "\[InvisibleSpace]", 
   "283.65203840530245`", "\[InvisibleSpace]", "\<\" kJ/mol\"\>"}],
  SequenceForm["Reaction barrier: ", 283.65203840530245`, " kJ/mol"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.437422248405652*^9}],

Cell[BoxData["\<\"Energies along the IRC:\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.437422250296731*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[0.005], 
    LineBox[{{-3.24499768, 1.420680666338696}, {-3.1405073, 
     3.9382722611165293`}, {-3.03528968, 7.589554595937627}, {-2.92758729, 
     12.202819995037537`}, {-2.81937738, 17.75968996098118}, {-2.71093924, 
     24.231021447894424`}, {-2.6025219, 31.591872209284887`}, {-2.49407894, 
     39.80469760051493}, {-2.38564506, 48.838254175870304`}, {-2.2772049, 
     58.659985740086476`}, {-2.16876811, 69.23602334782626}, {-2.06032868, 
     80.52803470457262}, {-1.95189081, 92.4905986666699}, {-1.84345134, 
     105.06910484193146`}, {-1.73501278, 118.1968655396217}, {-1.62657248, 
     131.79275282130274`}, {-1.51813347, 145.7577853508845}, {-1.40969332, 
     159.97197779529347`}, {-1.30125402, 174.29434082447276`}, {-1.19281333, 
     188.55920541174592`}, {-1.08437405, 
     202.5791108836109}, {-0.9759327980000001, 
     216.14480491951642`}, {-0.867494241, 229.03364515092375`}, {-0.759052219,
      241.0140625105614}, {-0.650616021, 251.85868873039024`}, {-0.542173085, 
     261.3532830407471}, {-0.433743052, 269.31301026767824`}, {-0.32530123, 
     275.59005478201016`}, {-0.21689052700000003`, 
     280.0896360471092}, {-0.10846103600000001`, 282.7705337188507}, {0., 
     283.6519139444745}, {0.10846971000000001`, 282.8091285633897}, {
     0.216902458, 280.3718772572823}, {0.325343716, 276.5110800520371}, {
     0.43378705300000003`, 271.42338686991104`}, {0.542230259, 
     265.31043608242214`}, {0.6506729280000001, 258.35312461408967`}, {
     0.759116199, 250.6916541450911}, {0.867561557, 242.4213303119922}, {
     0.9760091230000001, 233.60647785570382`}, {1.0844576, 
     224.30249481847855`}, {1.19290552, 214.5729182912732}, {1.30135204, 
     204.49730091295334`}, {1.40979687, 194.17042322000344`}, {1.51824012, 
     183.6975677476982}, {1.62668199, 173.18690508073334`}, {1.73512276, 
     162.74476795406107`}, {1.84356276, 152.46829985406532`}, {1.95200217, 
     142.44282951860296`}, {2.06044115, 132.73924543775408`}, {2.1688798, 
     123.41268310371198`}, {2.27731819, 114.50410031065395`}, {2.38575633, 
     106.04185245464933`}, {2.4941942, 98.04379293312653}, {2.60263173, 
     90.51937354482506}, {2.71106885, 83.47384528895346}, {2.81950548, 
     76.90878346523326}, {2.92794151, 70.82418807373907}, {3.03637685, 
     65.22189696417709}, {3.14481138, 60.10453563624487}, {3.25324494, 
     55.478142739030346`}}]}, 
   {RGBColor[0, 0, 1], Thickness[0.005], 
    LineBox[{{-3.24499768, 1.9215143298218933`}, {-3.1405073, 
     4.743753812411136}, {-3.03528968, 8.737554599433563}, {-2.92758729, 
     14.395577579503126`}, {-2.81937738, 21.481155336912266`}, {-2.71093924, 
     30.279439091449742`}, {-2.6025219, 40.84848791639189}, {-2.49407894, 
     53.35942121137087}, {-2.38564506, 67.96057120431072}, {-2.2772049, 
     84.82016096407509}, {-2.16876811, 104.11321564541203`}, {-2.06032868, 
     126.0191663412822}, {-1.95189081, 150.73114324740052`}, {-1.84345134, 
     178.44502415205335`}, {-1.73501278, 209.37793958292627`}, {-1.62657248, 
     243.7530168814688}, {-1.51813347, 
     281.8265868453299}, {-1.508265524346892, 285.65203840530245`}}]}, 
   {RGBColor[0., 0.75, 0.], Thickness[0.005], 
    LineBox[{{2.04889545658837, 285.65203840530245`}, {2.06044115, 
     281.33631720248474`}, {2.1688798, 245.68166650282822`}, {2.27731819, 
     214.3868313548077}, {2.38575633, 186.97520687307247`}, {2.4941942, 
     163.01517739800948`}, {2.60263173, 142.12072224692656`}, {2.71106885, 
     123.95018500941573`}, {2.81950548, 108.20325866277007`}, {2.92794151, 
     94.61670180059441}, {3.03637685, 82.95941995025053}, {3.14481138, 
     73.0277294680512}, {3.25324494, 64.64133082618406}}]}, 
   {GrayLevel[0], Thickness[0.004], 
    LineBox[{{-3.24499768, 1.7955593838252493`}, {-3.1405073, 
     4.17784540072114}, {-3.03528968, 7.604133473762805}, {-2.92758729, 
     12.12320849587466}, {-2.81937738, 17.63996517170174}, {-2.71093924, 
     24.132948133307963`}, {-2.6025219, 31.529751630020193`}, {-2.49407894, 
     39.79150367935758}, {-2.38564506, 48.859821847089336`}, {-2.2772049, 
     58.677856331766236`}, {-2.16876811, 69.18653598723476}, {-2.06032868, 
     80.32129978858582}, {-1.95189081, 92.02361301060216}, {-1.84345134, 
     104.22710764531233`}, {-1.73501278, 116.87647765323918`}, {-1.62657248, 
     129.9037131558597}, {-1.51813347, 143.25402081475883`}, {-1.40969332, 
     156.84749703490286`}, {-1.30125402, 170.61748582019672`}, {-1.19281333, 
     184.44751277940412`}, {-1.08437405, 
     198.23557719394762`}, {-0.9759327980000001, 
     211.79153600070285`}, {-0.867494241, 224.95390561473766`}, {-0.759052219,
      237.42783254441864`}, {-0.650616021, 248.9925421758766}, {-0.542173085, 
     259.26887429595814`}, {-0.433743052, 268.0290729774655}, {-0.32530123, 
     274.9381546661188}, {-0.21689052700000003`, 
     279.86861147946104`}, {-0.10846103600000001`, 282.7403287990008}, {0., 
     283.65203840552635`}, {0.10846971000000001`, 282.8444862146644}, {
     0.216902458, 280.6593472888738}, {0.325343716, 277.4662283399712}, {
     0.43378705300000003`, 273.5564447626923}, {0.542230259, 
     269.05215043013885`}, {0.6506729280000001, 263.8793528718897}, {
     0.759116199, 257.8324428115668}, {0.867561557, 250.70528047338294`}, {
     0.9760091230000001, 242.40660429793755`}, {1.0844576, 
     232.99363651024436`}, {1.19290552, 222.63690255916038`}, {1.30135204, 
     211.56880069479567`}, {1.40979687, 200.04367429878732`}, {1.51824012, 
     188.30976721361628`}, {1.62668199, 176.59000424263613`}, {1.73512276, 
     165.07027702844138`}, {1.84356276, 153.89431603191315`}, {1.95200217, 
     143.16397207303504`}, {2.06044115, 132.94331917522837`}, {2.1688798, 
     123.26514078676398`}, {2.27731819, 114.13859311059035`}, {2.38575633, 
     105.55715747604842`}, {2.4941942, 97.50602355632002}, {2.60263173, 
     89.968311590898}, {2.71106885, 82.92961943686724}, {2.81950548, 
     76.38067189611746}, {2.92794151, 70.31820395757563}, {3.03637685, 
     64.7444225859955}, {3.14481138, 59.665625241443145`}, {3.25324494, 
     55.09050485006657}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Reaction coordinate\"", TraditionalForm], 
    FormBox[
     FractionBox[
     "\"Energy\"", 
      "\"\\!\\(\\*SuperscriptBox[\\\"kJmol\\\", \\nRowBox[{\\\"-\\\", \\\"1\\\
\"}]]\\)\""], TraditionalForm]},
  AxesOrigin->{0, 0},
  ImageSize->{400, 300},
  PlotRange->{{-3.24499768, 3.25324494}, {0, 285.65203840530245`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.4374222504415627`*^9}],

Cell[BoxData["\<\"Red = IRC, Blue = \\!\\(\\*SubscriptBox[\\\"V\\\", \\\"11\\\
\"]\\), Green = \\!\\(\\*SubscriptBox[\\\"V\\\", \\\"22\\\"]\\), Black = \
EVB\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.4374222505553827`*^9}],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.4374222506414433`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Maximum energy error along the IRC: \"\>", "\[InvisibleSpace]",
    "8.800126442233749`", "\[InvisibleSpace]", "\<\" kJ/mol\"\>"}],
  SequenceForm[
  "Maximum energy error along the IRC: ", 8.800126442233749, " kJ/mol"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.437422250737294*^9}],

Cell[BoxData["\<\"Energy error along the IRC:\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.437422250823718*^9}],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.6, 0.4, 0.2], Thickness[0.005], 
   LineBox[{{-3.24499768, 0.3748787174865533}, {-3.1405073, 
    0.23957313960461132`}, {-3.03528968, 
    0.014578877825178266`}, {-2.92758729, -0.07961149916287506}, \
{-2.81937738, -0.11972478927944144`}, {-2.71093924, -0.09807331458646024}, \
{-2.6025219, -0.06212057926469089}, {-2.49407894, -0.01319392115735001}, \
{-2.38564506, 0.021567671219026294`}, {-2.2772049, 
    0.017870591679761863`}, {-2.16876811, -0.04948736059150467}, \
{-2.06032868, -0.20673491598680008`}, {-1.95189081, -0.46698565606773634`}, \
{-1.84345134, -0.8419971966191312}, {-1.73501278, -1.3203878863825245`}, \
{-1.62657248, -1.8890396654430421`}, {-1.51813347, -2.5037645361256713`}, \
{-1.40969332, -3.124480760390591}, {-1.30125402, -3.6768550042760406`}, \
{-1.19281333, -4.111692632341786}, {-1.08437405, -4.343533689663281}, \
{-0.9759327980000001, -4.3532689188135745`}, {-0.867494241, \
-4.079739536186104}, {-0.759052219, -3.586229966142736}, {-0.650616021, \
-2.8661465545136493`}, {-0.542173085, -2.084408744788908}, {-0.433743052, \
-1.283937290212743}, {-0.32530123, -0.6519001158913701}, \
{-0.21689052700000003`, -0.22102456764819392`}, {-0.10846103600000001`, \
-0.03020491984991768}, {0., 0.00012446105187183875`}, {0.10846971000000001`, 
    0.0353576512746701}, {0.216902458, 0.28747003159151785`}, {0.325343716, 
    0.9551482879341223}, {0.43378705300000003`, 2.133057892781263}, {
    0.542230259, 3.7417143477167456`}, {0.6506729280000001, 
    5.52622825780006}, {0.759116199, 7.140788666475743}, {0.867561557, 
    8.283950161390747}, {0.9760091230000001, 8.800126442233749}, {1.0844576, 
    8.69114169176582}, {1.19290552, 8.063984267887193}, {1.30135204, 
    7.071499781842338}, {1.40979687, 5.873251078783875}, {1.51824012, 
    4.612199465918073}, {1.62668199, 3.403099161902781}, {1.73512276, 
    2.3255090743802915`}, {1.84356276, 1.4260161778478455`}, {1.95200217, 
    0.721142554432095}, {2.06044115, 0.20407373747428573`}, {
    2.1688798, -0.14754231694801748`}, {2.27731819, -0.36550720006361637`}, {
    2.38575633, -0.48469497860091315`}, {2.4941942, -0.5377693768065078}, {
    2.60263173, -0.551061953927057}, {2.71106885, -0.5442258520862134}, {
    2.81950548, -0.5281115691157906}, {2.92794151, -0.5059841161634341}, {
    3.03637685, -0.4774743781815944}, {3.14481138, -0.4389103948017235}, {
    3.25324494, -0.3876378889637723}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Reaction coordinate\"", TraditionalForm], 
    FormBox[
     FractionBox[
     "\"Energy\"", 
      "\"\\!\\(\\*SuperscriptBox[\\\"kJmol\\\", \\nRowBox[{\\\"-\\\", \\\"1\\\
\"}]]\\)\""], TraditionalForm]},
  ImageSize->{400, 300},
  PlotRange->{-8.800126442233749, 8.800126442233749},
  PlotRangeClipping->True]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.43742225094809*^9}],

Cell[BoxData["\<\"\\!\\(\\*SuperscriptBox[SubscriptBox[\\\"V\\\", \
\\\"12\\\"], \\\"2\\\"]\\) along the IRC:\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.4374222511182737`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0.5, 0], Thickness[0.005], 
    LineBox[{{-3.24499768, 0.0004773213967683158}, {-3.1405073, 
     0.0007621514993952078}, {-3.03528968, 
     0.0010753168110070952`}, {-2.92758729, 
     0.002031399435618803}, {-2.81937738, 0.003400380207987193}, {-2.71093924,
      0.005441507397268568}, {-2.6025219, 0.008183036621334917}, {-2.49407894,
      0.01175092160773858}, {-2.38564506, 0.0162241575302756}, {-2.2772049, 
     0.02167665775496281}, {-2.16876811, 0.02816475346762228}, {-2.06032868, 
     0.03572302891605107}, {-1.95189081, 0.044374874757608894`}, {-1.84345134,
      0.05411855510955295}, {-1.73501278, 0.06494645460105898}, {-1.62657248, 
     0.0768251867899148}, {-1.51813347, 0.08972391286881623}, {-1.40969332, 
     0.10358361383204183`}, {-1.30125402, 0.11835957129122301`}, {-1.19281333,
      0.13396510242863066`}, {-1.08437405, 
     0.150349695707834}, {-0.9759327980000001, 
     0.16738316696096514`}, {-0.867494241, 
     0.18502051541800238`}, {-0.759052219, 
     0.20304677618380917`}, {-0.650616021, 
     0.22145612272740772`}, {-0.542173085, 
     0.23987247320089994`}, {-0.433743052, 
     0.25839294338545304`}, {-0.32530123, 
     0.2763979883097755}, {-0.21689052700000003`, 
     0.2940312213213383}, {-0.10846103600000001`, 0.31080296093893733`}, {0., 
     0.3261752537924433}, {0.10846971000000001`, 0.3398719468371033}, {
     0.216902458, 0.35126218361378597`}, {0.325343716, 0.3598524484132977}, {
     0.43378705300000003`, 0.3648116518251324}, {0.542230259, 
     0.36534639294449894`}, {0.6506729280000001, 0.3608527685349104}, {
     0.759116199, 0.35114689738686583`}, {0.867561557, 0.3366291387853913}, {
     0.9760091230000001, 0.3182232400936711}, {1.0844576, 
     0.2971014664422542}, {1.19290552, 0.2743910303322953}, {1.30135204, 
     0.2510162305189165}, {1.40979687, 0.22767226241845823`}, {1.51824012, 
     0.20485824714733458`}, {1.62668199, 0.18292386042292913`}, {1.73512276, 
     0.16210815945482832`}, {1.84356276, 0.14257010416802876`}, {1.95200217, 
     0.12440797243883832`}, {2.06044115, 0.10767343116995944`}, {2.1688798, 
     0.09238212926979963}, {2.27731819, 0.07852121226725557}, {2.38575633, 
     0.0660566217709726}, {2.4941942, 0.05493960505866722}, {2.60263173, 
     0.0451124271954665}, {2.71106885, 0.03651067741585697}, {2.81950548, 
     0.029066750157603058`}, {2.92794151, 0.022710202800090628`}, {3.03637685,
      0.017365306978254898`}, {3.14481138, 0.012952107462453812`}, {
     3.25324494, 0.009383950994784776}}]}, 
   {GrayLevel[0], Thickness[0.004], 
    LineBox[{{-3.24499768, 0.00012003498265977797`}, {-3.1405073, 
     0.0005354462825266637}, {-3.03528968, 
     0.0010616585668770107`}, {-2.92758729, 
     0.0021051788184731635`}, {-2.81937738, 
     0.003509841949991266}, {-2.71093924, 0.005529827289444178}, {-2.6025219, 
     0.008238036455917808}, {-2.49407894, 
     0.011762385710337497`}, {-2.38564506, 
     0.016205798871402166`}, {-2.2772049, 0.02166178217944026}, {-2.16876811, 
     0.028204967269432224`}, {-2.06032868, 0.03588674311013218}, {-1.95189081,
      0.044734659548645084`}, {-1.84345134, 
     0.05474863739287361}, {-1.73501278, 0.06590465894242126}, {-1.62657248, 
     0.0781526124605012}, {-1.51813347, 0.09142523018009996}, {-1.40969332, 
     0.10563405090113687`}, {-1.30125402, 0.1206876050157959}, {-1.19281333, 
     0.1364748128521711}, {-1.08437405, 
     0.15290457997437645`}, {-0.9759327980000001, 
     0.1698504611124232}, {-0.867494241, 0.18724983481873458`}, {-0.759052219,
      0.20493783605731242`}, {-0.650616021, 
     0.2229174884175542}, {-0.542173085, 0.24090235381025238`}, {-0.433743052,
      0.2590099977828242}, {-0.32530123, 
     0.27670383413045396`}, {-0.21689052700000003`, 
     0.2941329928017806}, {-0.10846103600000001`, 0.31081668555969966`}, {0., 
     0.32617519766579495`}, {0.10846971000000001`, 0.3398560239493582}, {
     0.216902458, 0.3511321298595522}, {0.325343716, 0.35941582883435963`}, {
     0.43378705300000003`, 0.36382150424130444`}, {0.542230259, 
     0.3635754757009293}, {0.6506729280000001, 0.35817765009009417`}, {
     0.759116199, 0.34760320834902725`}, {0.867561557, 0.3324069643134422}, {
     0.9760091230000001, 0.3136089551596064}, {1.0844576, 
     0.2924051406483308}, {1.19290552, 0.26989251985550355`}, {1.30135204, 
     0.24693670013146063`}, {1.40979687, 0.2241630673141537}, {1.51824012, 
     0.2020007853446515}, {1.62668199, 0.18073589390291733`}, {1.73512276, 
     0.16055591924554813`}, {1.84356276, 0.14158187111693943`}, {1.95200217, 
     0.1238892648427079}, {2.06044115, 0.10752116619365326`}, {2.1688798, 
     0.09249622722771567}, {2.27731819, 0.07881386546630709}, {2.38575633, 
     0.06645794759863177}, {2.4941942, 0.055399451834209135`}, {2.60263173, 
     0.04559836173674525}, {2.71106885, 0.03700482143214345}, {2.81950548, 
     0.029559705655000768`}, {2.92794151, 0.023194953501734616`}, {3.03637685,
      0.017834023413320854`}, {3.14481138, 0.01339285064945539}, {3.25324494, 
     0.009781465083994245}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Reaction coordinate\"", TraditionalForm], 
    FormBox[
     FractionBox[
     "\"Energy\"", 
      "\"\\!\\(\\*SuperscriptBox[\\\"Hartree\\\", \\\"2\\\"]\\)\""], 
     TraditionalForm]},
  AxesOrigin->{0, 0},
  ImageSize->{400, 300},
  PlotRange->{{-3.24499768, 3.25324494}, {0., 0.36534639294449894`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.437422251294971*^9}],

Cell[BoxData["\<\"Orange = IRC, Black = EVB\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.437422251440703*^9}],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.4374222515223827`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Maximum \\!\\(\\*SuperscriptBox[SubscriptBox[\\\"V\\\", \\\"12\
\\\"], \\\"2\\\"]\\) error along the IRC: \"\>", "\[InvisibleSpace]", 
   "0.004696325793923428`", "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", 
   FractionBox["\<\"Energy\"\>", \
"\<\"\\!\\(\\*SuperscriptBox[\\\"Hartree\\\", \\\"2\\\"]\\)\"\>"]}],
  SequenceForm[
  "Maximum \!\(\*SuperscriptBox[SubscriptBox[\"V\", \"12\"], \"2\"]\) error \
along the IRC: ", 0.004696325793923428, " ", "Energy"/
   "\!\(\*SuperscriptBox[\"Hartree\", \"2\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.437422251609418*^9}],

Cell[BoxData["\<\"\\!\\(\\*SuperscriptBox[SubscriptBox[\\\"V\\\", \
\\\"12\\\"], \\\"2\\\"]\\) error along the IRC:\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.437422251692162*^9}],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.6, 0.4, 0.2], Thickness[0.005], 
   LineBox[{{-3.24499768, -0.00035728641410853783`}, {-3.1405073, \
-0.00022670521686854407`}, {-3.03528968, -0.00001365824413008458}, \
{-2.92758729, 0.00007377938285436057}, {-2.81937738, 
    0.0001094617420040727}, {-2.71093924, 0.0000883198921756102}, {-2.6025219,
     0.000054999834582890664`}, {-2.49407894, 
    0.000011464102598918169`}, {-2.38564506, -0.000018358658873434547`}, \
{-2.2772049, -0.000014875575522550755`}, {-2.16876811, 
    0.000040213801809945576`}, {-2.06032868, 
    0.00016371419408110766`}, {-1.95189081, 
    0.0003597847910361898}, {-1.84345134, 
    0.0006300822833206626}, {-1.73501278, 0.000958204341362276}, {-1.62657248,
     0.001327425670586399}, {-1.51813347, 
    0.0017013173112837288`}, {-1.40969332, 
    0.0020504370690950374`}, {-1.30125402, 
    0.002328033724572881}, {-1.19281333, 0.002509710423540451}, {-1.08437405, 
    0.002554884266542462}, {-0.9759327980000001, 
    0.0024672941514580493`}, {-0.867494241, 
    0.002229319400732205}, {-0.759052219, 
    0.0018910598735032424`}, {-0.650616021, 
    0.0014613656901464878`}, {-0.542173085, 
    0.0010298806093524404`}, {-0.433743052, 
    0.0006170543973711418}, {-0.32530123, 
    0.0003058458206784409}, {-0.21689052700000003`, 
    0.00010177148044232531`}, {-0.10846103600000001`, 
    0.00001372462076232317}, {0., -5.612664832899128*^-8}, {
    0.10846971000000001`, -0.0000159228877451012}, {
    0.216902458, -0.00013005375423374987`}, {
    0.325343716, -0.0004366195789380911}, {
    0.43378705300000003`, -0.0009901475838279827}, {
    0.542230259, -0.0017709172435696474`}, {
    0.6506729280000001, -0.0026751184448162157`}, {
    0.759116199, -0.003543689037838582}, {
    0.867561557, -0.004222174471949114}, {
    0.9760091230000001, -0.004614284934064683}, {
    1.0844576, -0.004696325793923428}, {1.19290552, -0.004498510476791728}, {
    1.30135204, -0.004079530387455899}, {1.40979687, -0.00350919510430453}, {
    1.51824012, -0.0028574618026830922`}, {
    1.62668199, -0.002187966520011797}, {
    1.73512276, -0.0015522402092801868`}, {
    1.84356276, -0.0009882330510893322}, {
    1.95200217, -0.0005187075961304161}, {
    2.06044115, -0.00015226497630617397`}, {2.1688798, 
    0.00011409795791603172`}, {2.27731819, 0.0002926531990515152}, {
    2.38575633, 0.00040132582765917135`}, {2.4941942, 
    0.0004598467755419153}, {2.60263173, 0.00048593454127875135`}, {
    2.71106885, 0.000494144016286481}, {2.81950548, 0.0004929554973977096}, {
    2.92794151, 0.0004847507016439885}, {3.03637685, 
    0.00046871643506595645`}, {3.14481138, 0.0004407431870015778}, {
    3.25324494, 0.0003975140892094695}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Reaction coordinate\"", TraditionalForm], 
    FormBox[
     FractionBox[
     "\"Energy\"", 
      "\"\\!\\(\\*SuperscriptBox[\\\"Hartree\\\", \\\"2\\\"]\\)\""], 
     TraditionalForm]},
  ImageSize->{400, 300},
  PlotRange->{-0.004696325793923428, 0.004696325793923428},
  PlotRangeClipping->True]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.437422251813068*^9}],

Cell[BoxData["\<\"Gradient Norm along the IRC:\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.437422251987805*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0., 0.75, 0.], Thickness[0.005], 
    LineBox[{{-3.24499768, 0.021495469849465473`}, {-3.1405073, 
     0.030077283659675984`}, {-3.03528968, 0.03147299599096353}, {-2.92758729,
      0.03645175918884778}, {-2.81937738, 0.04212578023914487}, {-2.71093924, 
     0.048377868803392676`}, {-2.6025219, 0.054040446653656}, {-2.49407894, 
     0.059590343030477395`}, {-2.38564506, 0.06471865515073867}, {-2.2772049, 
     0.06962509258473884}, {-2.16876811, 0.07415012468102451}, {-2.06032868, 
     0.07836945293689208}, {-1.95189081, 0.0821531231329938}, {-1.84345134, 
     0.08551079179027314}, {-1.73501278, 0.08830051914863637}, {-1.62657248, 
     0.09048566947799994}, {-1.51813347, 0.09189347002911705}, {-1.40969332, 
     0.09245949886302529}, {-1.30125402, 0.09198148794273778}, {-1.19281333, 
     0.09040753526969492}, {-1.08437405, 
     0.08752869307739591}, {-0.9759327980000001, 
     0.08337723614747664}, {-0.867494241, 0.07776888487883121}, {-0.759052219,
      0.07091230891735942}, {-0.650616021, 
     0.06266027112967809}, {-0.542173085, 0.0534710542305213}, {-0.433743052, 
     0.043219882083693956`}, {-0.32530123, 
     0.03258258755533875}, {-0.21689052700000003`, 
     0.02148705575790231}, {-0.10846103600000001`, 0.010560714224430208`}, {
     0., 0.00004903303674735477}, {0.10846971000000001`, 
     0.009864674512858895}, {0.216902458, 0.018799561866197897`}, {
     0.325343716, 0.026632427336043207`}, {0.43378705300000003`, 
     0.0332707189952057}, {0.542230259, 0.03875225679674378}, {
     0.6506729280000001, 0.04324421065702251}, {0.759116199, 
     0.047001267724649846`}, {0.867561557, 0.05027559951088567}, {
     0.9760091230000001, 0.0532305190083605}, {1.0844576, 
     0.055911792373121265`}, {1.19290552, 0.05827770252907679}, {1.30135204, 
     0.06024970269400953}, {1.40979687, 0.06175130154225867}, {1.51824012, 
     0.06272875711314368}, {1.62668199, 0.06315845538333383}, {1.73512276, 
     0.0630461517453146}, {1.84356276, 0.06242171502101128}, {1.95200217, 
     0.06133181173011929}, {2.06044115, 0.05983248828955725}, {2.1688798, 
     0.05798305370366361}, {2.27731819, 0.05584185817409674}, {2.38575633, 
     0.05346368508767874}, {2.4941942, 0.05089798089774712}, {2.60263173, 
     0.048187203182166904`}, {2.71106885, 0.045365057411209254`}, {2.81950548,
      0.042454892471421535`}, {2.92794151, 0.039468778720615307`}, {
     3.03637685, 0.03640768129440806}, {3.14481138, 0.03326290892540397}, {
     3.25324494, 0.03001864601478904}}]}, 
   {RGBColor[1, 1, 0], Thickness[0.005], 
    LineBox[{{-3.24499768, 0.01591199084847161}, {-3.1405073, 
     0.021998804523516446`}, {-3.03528968, 0.02364381182380428}, {-2.92758729,
      0.027322546127017112`}, {-2.81937738, 
     0.03175504392141258}, {-2.71093924, 0.03626251864936085}, {-2.6025219, 
     0.04043836499469243}, {-2.49407894, 0.04439590203393254}, {-2.38564506, 
     0.04806264380580911}, {-2.2772049, 0.05148965149153292}, {-2.16876811, 
     0.05463304140321211}, {-2.06032868, 0.05749999386628722}, {-1.95189081, 
     0.06004021430624983}, {-1.84345134, 0.06222951205782343}, {-1.73501278, 
     0.06399905300533483}, {-1.62657248, 0.0652968898038087}, {-1.51813347, 
     0.06603181670739365}, {-1.40969332, 0.06613271926804806}, {-1.30125402, 
     0.06549567521010197}, {-1.19281333, 0.06405468915894896}, {-1.08437405, 
     0.0617194607555649}, {-0.9759327980000001, 
     0.05847066667860296}, {-0.867494241, 0.05426663210261952}, {-0.759052219,
      0.04918077277017922}, {-0.650616021, 0.0432444810488786}, {-0.542173085,
      0.03664763432404994}, {-0.433743052, 
     0.029494727947590272`}, {-0.32530123, 
     0.02205691329910159}, {-0.21689052700000003`, 
     0.014504694308245731`}, {-0.10846103600000001`, 0.00706783961279983}, {
     0., 0.00003219664198348302}, {0.10846971000000001`, 
     0.006545699449447691}, {0.216902458, 0.0124207071722431}, {0.325343716, 
     0.017534346889864428`}, {0.43378705300000003`, 0.021846759172359117`}, {
     0.542230259, 0.025405312406371963`}, {0.6506729280000001, 
     0.028340215173036323`}, {0.759116199, 0.030835118522050176`}, {
     0.867561557, 0.03306625554218077}, {0.9760091230000001, 
     0.035145246437190955`}, {1.0844576, 0.03710135934370932}, {1.19290552, 
     0.03890264054727543}, {1.30135204, 0.04048966728232992}, {1.40979687, 
     0.04180113901761616}, {1.51824012, 0.042787822675827175`}, {1.62668199, 
     0.04341825352714558}, {1.73512276, 0.043679566573776814`}, {1.84356276, 
     0.043575680459944977`}, {1.95200217, 0.043124140959321836`}, {2.06044115,
      0.04235254754243799}, {2.1688798, 0.041295169517435004`}, {2.27731819, 
     0.03999000160079368}, {2.38575633, 0.03847617256572842}, {2.4941942, 
     0.03679149190662542}, {2.60263173, 0.03497001762472366}, {2.71106885, 
     0.03303977983857431}, {2.81950548, 0.031020983735931776`}, {2.92794151, 
     0.028925042299357172`}, {3.03637685, 0.026754644349461967`}, {3.14481138,
      0.024504880715405235`}, {3.25324494, 0.022165230785659833`}}]}, 
   {GrayLevel[0], Thickness[0.004], 
    LineBox[{{-3.24499768, 0.011852180324848426`}, {-3.1405073, 
     0.01636624474911355}, {-3.03528968, 0.02265258054893149}, {-2.92758729, 
     0.028089313059052507`}, {-2.81937738, 
     0.034058995132000836`}, {-2.71093924, 0.03983919271883582}, {-2.6025219, 
     0.04554296761529472}, {-2.49407894, 0.05113412067588722}, {-2.38564506, 
     0.0565224137978686}, {-2.2772049, 0.06169538893767102}, {-2.16876811, 
     0.06654177418980876}, {-2.06032868, 0.07102118580414933}, {-1.95189081, 
     0.07501339629204487}, {-1.84345134, 0.0784555697482235}, {-1.73501278, 
     0.08121736081199599}, {-1.62657248, 0.08322346444791583}, {-1.51813347, 
     0.08433385136447753}, {-1.40969332, 0.0844748542304703}, {-1.30125402, 
     0.08350256919891576}, {-1.19281333, 0.08137200240648976}, {-1.08437405, 
     0.07795201701607513}, {-0.9759327980000001, 
     0.0732799199406854}, {-0.867494241, 0.06726960983210498}, {-0.759052219, 
     0.06012981394445143}, {-0.650616021, 0.05186203561656164}, {-0.542173085,
      0.042941182553385325`}, {-0.433743052, 
     0.03348769557958969}, {-0.32530123, 
     0.024199201608003696`}, {-0.21689052700000003`, 
     0.015284696251656777`}, {-0.10846103600000001`, 0.007208610137471334}, {
     0., 0.000032194298499727374`}, {0.10846971000000001`, 
     0.0066395323186922445`}, {0.216902458, 0.01331875760235377}, {
     0.325343716, 0.020699468210081187`}, {0.43378705300000003`, 
     0.02901735134095379}, {0.542230259, 0.037993873142601685`}, {
     0.6506729280000001, 0.04702657592079008}, {0.759116199, 
     0.05551852054871822}, {0.867561557, 0.06312226339786921}, {
     0.9760091230000001, 0.06976421365854046}, {1.0844576, 
     0.07549211698952424}, {1.19290552, 0.0803215917922998}, {1.30135204, 
     0.08419136042723076}, {1.40979687, 0.08700106913752881}, {1.51824012, 
     0.08866590963313767}, {1.62668199, 0.08915281397999861}, {1.73512276, 
     0.08849224703838807}, {1.84356276, 0.08677217667991377}, {1.95200217, 
     0.08412280474937207}, {2.06044115, 0.08069861590069508}, {2.1688798, 
     0.07666161459618077}, {2.27731819, 0.07216778815184884}, {2.38575633, 
     0.06735771685099454}, {2.4941942, 0.06235133366546512}, {2.60263173, 
     0.057246499295880764`}, {2.71106885, 0.05212058927511634}, {2.81950548, 
     0.0470339820959224}, {2.92794151, 0.042034370112597745`}, {3.03637685, 
     0.037160823935685296`}, {3.14481138, 0.032446975057580166`}, {3.25324494,
      0.027922785972112906`}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Reaction coordinate\"", TraditionalForm], 
    FormBox["\"Gradient Norm\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  ImageSize->{400, 300},
  PlotRange->{{-3.24499768, 3.25324494}, {0., 0.09245949886302529}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.437422252280751*^9}],

Cell[BoxData["\<\"Green = Cartesian, Yellow = Red. Internal, Black = \
EVB\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.437422252394102*^9}],

Cell[BoxData["\<\"\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.4374222524637814`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Maximum Gradient Norm error along the IRC: \"\>", 
   "\[InvisibleSpace]", "0.04587808695731049`"}],
  SequenceForm[
  "Maximum Gradient Norm error along the IRC: ", 0.04587808695731049],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.4374222525242043`*^9}],

Cell[BoxData["\<\"Gradient Norm error along the IRC:\"\>"], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.437422252587484*^9}],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.6, 0.4, 0.2], Thickness[0.005], 
   LineBox[{{-3.24499768, -0.0040598105236231835`}, {-3.1405073, \
-0.005632559774402895}, {-3.03528968, -0.0009912312748727899}, {-2.92758729, 
    0.0007667669320353954}, {-2.81937738, 
    0.0023039512105882537`}, {-2.71093924, 
    0.0035766740694749694`}, {-2.6025219, 
    0.0051046026206022915`}, {-2.49407894, 
    0.006738218641954681}, {-2.38564506, 0.008459769992059489}, {-2.2772049, 
    0.010205737446138098`}, {-2.16876811, 
    0.011908732786596654`}, {-2.06032868, 0.01352119193786211}, {-1.95189081, 
    0.014973181985795038`}, {-1.84345134, 
    0.016226057690400073`}, {-1.73501278, 
    0.017218307806661157`}, {-1.62657248, 0.01792657464410713}, {-1.51813347, 
    0.018302034657083882`}, {-1.40969332, 
    0.018342134962422235`}, {-1.30125402, 0.01800689398881379}, {-1.19281333, 
    0.017317313247540794`}, {-1.08437405, 
    0.016232556260510227`}, {-0.9759327980000001, 
    0.01480925326208244}, {-0.867494241, 
    0.013002977729485457`}, {-0.759052219, 
    0.010949041174272214`}, {-0.650616021, 
    0.008617554567683046}, {-0.542173085, 
    0.006293548229335387}, {-0.433743052, 0.003992967631999415}, {-0.32530123,
     0.0021422883089021044`}, {-0.21689052700000003`, 
    0.0007800019434110461}, {-0.10846103600000001`, 
    0.00014077052467150342`}, {0., -2.3434837556434275`*^-9}, {
    0.10846971000000001`, 0.00009383286924455336}, {0.216902458, 
    0.0008980504301106702}, {0.325343716, 0.0031651213202167593`}, {
    0.43378705300000003`, 0.007170592168594673}, {0.542230259, 
    0.012588560736229722`}, {0.6506729280000001, 0.018686360747753754`}, {
    0.759116199, 0.024683402026668043`}, {0.867561557, 0.03005600785568844}, {
    0.9760091230000001, 0.03461896722134951}, {1.0844576, 
    0.03839075764581492}, {1.19290552, 0.04141895124502438}, {1.30135204, 
    0.043701693144900834`}, {1.40979687, 0.04519993011991265}, {1.51824012, 
    0.04587808695731049}, {1.62668199, 0.045734560452853026`}, {1.73512276, 
    0.04481268046461125}, {1.84356276, 0.043196496219968794`}, {1.95200217, 
    0.04099866379005024}, {2.06044115, 0.03834606835825709}, {2.1688798, 
    0.03536644507874577}, {2.27731819, 0.03217778655105515}, {2.38575633, 
    0.02888154428526612}, {2.4941942, 0.0255598417588397}, {2.60263173, 
    0.022276481671157103`}, {2.71106885, 0.01908080943654203}, {2.81950548, 
    0.01601299835999062}, {2.92794151, 0.013109327813240573`}, {3.03637685, 
    0.010406179586223328`}, {3.14481138, 0.007942094342174931}, {3.25324494, 
    0.005757555186453073}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Reaction coordinate\"", TraditionalForm], 
    FormBox["\"Gradient Norm\"", TraditionalForm]},
  ImageSize->{400, 300},
  PlotRange->{-0.04587808695731049, 0.04587808695731049},
  PlotRangeClipping->True]], "Print",
 CellChangeTimes->{
  3.4374002906638947`*^9, 3.4374014704230433`*^9, 3.437402603718886*^9, 
   3.4374028823931026`*^9, 3.4374029533724413`*^9, 3.43740689900038*^9, 
   3.437407145107781*^9, 3.437408677700461*^9, 3.4374088708400507`*^9, 
   3.43740901549175*^9, {3.437412607927227*^9, 3.4374126259913807`*^9}, 
   3.4374129505640306`*^9, 3.437413366890092*^9, 3.437413421842279*^9, 
   3.4374215696478033`*^9, 3.4374219655494547`*^9, 3.437422001936755*^9, 
   3.437422036622079*^9, 3.437422097651107*^9, 3.437422165956328*^9, 
   3.4374222149213963`*^9, 3.437422252673527*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBinUse", "[", "]"}]], "Input",
 CellChangeTimes->{{3.4374073082264547`*^9, 3.437407310628818*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Currently using \"\>", "\[InvisibleSpace]", 
   "9.96234130859375`", "\[InvisibleSpace]", "\<\" MB of memory.\"\>"}],
  SequenceForm["Currently using ", 9.96234130859375, " MB of memory."],
  Editable->False]], "Print",
 CellChangeTimes->{3.437407311125369*^9, 3.437408979449183*^9, 
  3.437413088450337*^9, 3.437413564045677*^9, 3.437421574553267*^9, 
  3.4374219696852493`*^9, 3.437422006742056*^9, 3.4374220411802*^9, 
  3.437422102187806*^9, 3.437422170678131*^9, 3.437422219997026*^9, 
  3.4374222529998903`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{997, 923},
WindowMargins->{{108, Automatic}, {-21, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"6.0 for Mac OS X PowerPC (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3437404247-9902564"->{
  Cell[58350, 1403, 407, 7, 108, "Print",
   CellTags->"Info3437404247-9902564"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3437404247-9902564", 104838, 2222}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 132, 1, 69, "Subtitle"],
Cell[725, 26, 1368, 23, 534, "Text"],
Cell[CellGroupData[{
Cell[2118, 53, 32, 0, 100, "Section"],
Cell[CellGroupData[{
Cell[2175, 57, 200, 5, 40, "Input"],
Cell[2378, 64, 472, 9, 70, "Output"]
}, Open  ]],
Cell[2865, 76, 58, 1, 40, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[2960, 82, 24, 0, 53, "Section"],
Cell[2987, 84, 232, 5, 39, "Text"],
Cell[CellGroupData[{
Cell[3244, 93, 172, 4, 42, "Subsection"],
Cell[3419, 99, 223, 6, 42, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3679, 110, 244, 7, 42, "Subsection"],
Cell[3926, 119, 282, 8, 90, "Input"],
Cell[4211, 129, 411, 10, 65, "Input"],
Cell[4625, 141, 726, 23, 133, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5388, 169, 48, 0, 51, "Subsection"],
Cell[5439, 171, 274, 8, 64, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5750, 184, 116, 3, 51, "Subsection"],
Cell[5869, 189, 120, 3, 40, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6026, 197, 212, 5, 42, "Subsection"],
Cell[CellGroupData[{
Cell[6263, 206, 56, 1, 40, "Input"],
Cell[6322, 209, 366, 6, 40, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6737, 221, 278, 6, 42, "Subsection"],
Cell[7018, 229, 255, 6, 40, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7310, 240, 193, 4, 42, "Subsection"],
Cell[7506, 246, 176, 4, 40, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7731, 256, 28, 0, 100, "Section"],
Cell[CellGroupData[{
Cell[7784, 260, 62, 0, 37, "Subsubsection"],
Cell[7849, 262, 315, 9, 65, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[8201, 276, 107, 2, 26, "Subsubsection"],
Cell[8311, 280, 259, 9, 42, "Input"],
Cell[8573, 291, 259, 9, 42, "Input"],
Cell[8835, 302, 228, 6, 42, "Input"],
Cell[9066, 310, 227, 6, 42, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[9330, 321, 55, 1, 29, "Input"],
Cell[9388, 324, 527, 10, 70, "Print"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[9964, 340, 39, 0, 53, "Section"],
Cell[CellGroupData[{
Cell[10028, 344, 559, 9, 40, "Input"],
Cell[10590, 355, 2142, 31, 40, "Output"]
}, Open  ]],
Cell[12747, 389, 2875, 54, 156, "Input"],
Cell[CellGroupData[{
Cell[15647, 447, 1611, 37, 179, "Input"],
Cell[17261, 486, 2668, 39, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19966, 530, 62, 1, 40, "Input"],
Cell[20031, 533, 1637, 33, 170, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21705, 571, 715, 12, 87, "Input"],
Cell[22423, 585, 660, 12, 30, "Print"],
Cell[23086, 599, 815, 17, 30, "Print"],
Cell[23904, 618, 815, 17, 30, "Print"],
Cell[24722, 637, 630, 13, 30, "Print"],
Cell[25355, 652, 480, 7, 30, "Print"],
Cell[25838, 661, 451, 7, 30, "Print"],
Cell[26292, 670, 451, 7, 30, "Print"],
Cell[26746, 679, 454, 7, 30, "Print"],
Cell[27203, 688, 453, 7, 30, "Print"],
Cell[27659, 697, 654, 12, 30, "Print"],
Cell[28316, 711, 658, 12, 30, "Print"],
Cell[28977, 725, 644, 12, 30, "Print"],
Cell[29624, 739, 1416, 37, 115, "Print"],
Cell[31043, 778, 820, 18, 30, "Print"],
Cell[31866, 798, 465, 7, 30, "Print"],
Cell[32334, 807, 1598, 36, 77, "Print"],
Cell[33935, 845, 464, 7, 30, "Print"],
Cell[34402, 854, 1329, 28, 73, "Print"],
Cell[35734, 884, 462, 7, 30, "Print"],
Cell[36199, 893, 1523, 36, 77, "Print"],
Cell[37725, 931, 738, 13, 30, "Print"],
Cell[38466, 946, 603, 9, 30, "Print"],
Cell[39072, 957, 4679, 77, 462, "Print"],
Cell[43754, 1036, 739, 15, 34, "Print"],
Cell[44496, 1053, 729, 15, 30, "Print"],
Cell[45228, 1070, 1417, 37, 115, "Print"],
Cell[46648, 1109, 479, 7, 30, "Print"],
Cell[47130, 1118, 466, 7, 30, "Print"],
Cell[47599, 1127, 671, 13, 30, "Print"],
Cell[48273, 1142, 808, 16, 34, "Print"],
Cell[49084, 1160, 565, 11, 30, "Print"],
Cell[49652, 1173, 612, 12, 34, "Print"],
Cell[50267, 1187, 811, 18, 462, "Print"],
Cell[51081, 1207, 651, 12, 30, "Print"],
Cell[51735, 1221, 632, 12, 30, "Print"],
Cell[52370, 1235, 638, 12, 30, "Print"],
Cell[53011, 1249, 616, 12, 30, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53664, 1266, 183, 4, 42, "Subsection"],
Cell[53850, 1272, 466, 12, 64, "Input"],
Cell[54319, 1286, 200, 4, 40, "Input"],
Cell[CellGroupData[{
Cell[54544, 1294, 55, 1, 40, "Input"],
Cell[54602, 1297, 923, 15, 30, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[55586, 1319, 38, 0, 100, "Section"],
Cell[CellGroupData[{
Cell[55649, 1323, 1050, 31, 172, "Input"],
Cell[56702, 1356, 634, 15, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57373, 1376, 142, 2, 40, "Input"],
Cell[57518, 1380, 642, 13, 64, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58197, 1398, 150, 3, 40, "Input"],
Cell[58350, 1403, 407, 7, 108, "Print",
 CellTags->"Info3437404247-9902564"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58794, 1415, 470, 7, 40, "Input"],
Cell[59267, 1424, 840, 14, 30, "Print"],
Cell[60110, 1440, 634, 9, 30, "Print"],
Cell[60747, 1451, 7270, 114, 462, "Print"],
Cell[68020, 1567, 752, 11, 30, "Print"],
Cell[68775, 1580, 613, 9, 30, "Print"],
Cell[69391, 1591, 876, 15, 30, "Print"],
Cell[70270, 1608, 638, 9, 30, "Print"],
Cell[70911, 1619, 3443, 57, 462, "Print"],
Cell[74357, 1678, 704, 10, 34, "Print"],
Cell[75064, 1690, 6188, 104, 462, "Print"],
Cell[81255, 1796, 636, 9, 30, "Print"],
Cell[81894, 1807, 613, 9, 30, "Print"],
Cell[82510, 1818, 1181, 21, 54, "Print"],
Cell[83694, 1841, 708, 10, 34, "Print"],
Cell[84405, 1853, 3717, 72, 462, "Print"],
Cell[88125, 1927, 639, 9, 30, "Print"],
Cell[88767, 1938, 8597, 132, 462, "Print"],
Cell[97367, 2072, 667, 10, 30, "Print"],
Cell[98037, 2084, 613, 9, 30, "Print"],
Cell[98653, 2095, 845, 15, 30, "Print"],
Cell[99501, 2112, 645, 9, 30, "Print"],
Cell[100149, 2123, 3498, 60, 462, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103684, 2188, 123, 2, 40, "Input"],
Cell[103810, 2192, 566, 10, 30, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
